package org.bouncycastle.jce.cert;

import java.security.cert.Certificate;

/**
 * A selector that defines a set of criteria for selecting
 *  Certificate</code>s. Classes that implement this interface
 * are often used to specify which  Certificate</code>s should
 * be retrieved from a  CertStore</code>.<br />
 * <br />
 * <b>Concurrent Access</b><br />
 * <br />
 * Unless otherwise specified, the methods defined in this interface are not
 * thread-safe. Multiple threads that need to access a single
 * object concurrently should synchronize amongst themselves and
 * provide the necessary locking. Multiple threads each manipulating
 * separate objects need not synchronize.
 *
 * @see Certificate
 * @see CertStore
 * @see CertStore#getCertificates
 */
public interface CertSelector extends Cloneable
{
        /**
     * Decides whether a  Certificate</code> should be selected.
     *
     * @param cert the  Certificate</code> to be checked
     * @return  true</code> if the  Certificate</code> 
     * should be selected,  false</code> otherwise
     */
    public boolean match(Certificate cert);

    /**
     * Makes a copy of this  CertSelector</code>. Changes to the 
     * copy will not affect the original and vice versa.
     *
     * @return a copy of this  CertSelector</code>
     */
    public Object clone();
}
